# SAFE-PFL utils

![Python](https://img.shields.io/badge/python-3.12-blue.svg)
![Docs](https://github.com/safe-pfl/plotter/workflows/docs/badge.svg)

## What safe-pfl-utils does

`safe-pfl-utils` is a pip package that helps developers / researchers to use the [SAFE-PFL](https://github.com/safe-pfl/safe-pfl).

## How to install safe-pfl-utils

To install this package run:

```sh
pip install safe-pfl-utils --user
```

## Get started using safe-pfl-utils

For usage refer to [Examples](https://github.com/safe-pfl/examples/plotter) repository.

## Package documentation

Visit [this](https://safe-pfl.github.io/safe-pfl-utils/) github pages for this package detailed documentation.
